@@ -61,7 +61,7 @@
  *  - triple check apache process lifecycle works right when do the clean
  *    shutdown rather than abrupt exit().
  *  - DBD_PARAMS and DBD_DRIVER should not be required when using helper
- *  - Use /usr/sbin/vncproxy helper by default
+ *  - Use /usr/bin/vncproxy helper by default
  *  - Only required configuration (usable) should be vncProxy On
  */
 
@@ -156,8 +156,6 @@ typedef struct vncproxy_cfg
 	char *loc; /* Location to which this record applies. */
 
 	const char *dir;
-	const char *vncProxySignedApplet;
-	const char *vncProxyUnsignedApplet;
 	const char *vncProxyConnectionQuery;
 	const char *_vncProxyConnectionQueryLabel;
 	const char *vncProxyHelperStderr;
@@ -172,7 +170,7 @@ typedef struct vncproxy_cfg
 } vncproxy_cfg;
 
 static const char *vncproxy_banner() {
-	return "mod_vncproxy/1.0";
+	return "mod_vncproxy/1.0.2";
 	return ap_get_server_version();
 }
 
@@ -424,26 +422,6 @@ static const char *cmd_vncProxyShutdownSSLOnExec(cmd_parms *cmd, void *mconfig,
 	return NULL;
 }
 
-static const char *cmd_vncProxySignedApplet(cmd_parms *cmd, void *mconfig, const char *param)
-{
-	vncproxy_cfg *cfg = (vncproxy_cfg *) mconfig;
-
-	ap_log_error(APLOG_MARK, APLOG_DEBUG, 0, cmd->server, "cmd_vncProxySignedApplet(\"%s\")", param);
-
-	cfg->vncProxySignedApplet = param;
-	return NULL;
-}
-
-static const char *cmd_vncProxyUnsignedApplet(cmd_parms *cmd, void *mconfig, const char *param)
-{
-	vncproxy_cfg *cfg = (vncproxy_cfg *) mconfig;
-
-	ap_log_error(APLOG_MARK, APLOG_DEBUG, 0, cmd->server, "cmd_vncProxyUnsignedApplet(\"%s\")", param);
-
-	cfg->vncProxyUnsignedApplet = param;
-	return NULL;
-}
-
 static const char *cmd_vncProxyConnectionQuery(cmd_parms *cmd, void *mconfig, const char *param)
 {
 	vncproxy_cfg *cfg = (vncproxy_cfg *) mconfig;
@@ -489,7 +467,7 @@ static const char *cmd_vncProxyDBDParams(cmd_parms *cmd, void *mconfig, const ch
  *
  * Example:
  *
- *      vncProxyHelper /usr/sbin/vncproxy --token=%t --remoteip=%r
+ *      vncProxyHelper /usr/bin/vncproxy %t 
  *
  */
 
@@ -634,20 +612,6 @@ static const command_rec vncproxy_cmds[] = {
 		"VNC proxy CONNECT requests may connect to during an SSL session"),
 	AP_INIT_ITERATE("vncProxyAllowedPorts", cmd_vncProxyAllowedPorts, NULL, RSRC_CONF, "A list of ports which "
 		"VNC proxy CONNECT requests may connect to during an non-SSL session"),
-	AP_INIT_TAKE1(
-				"vncProxySignedApplet", /* directive name */
-				cmd_vncProxySignedApplet, /* config action routine */
-				NULL, /* argument to include in call */
-				OR_OPTIONS, /* where available */
-				"vncProxySignedApplet directive - no arguments" /* directive description */
-				),
-	AP_INIT_TAKE1(
-				"vncProxyUnsignedApplet", /* directive name */
-				cmd_vncProxyUnsignedApplet, /* config action routine */
-				NULL, /* argument to include in call */
-				OR_OPTIONS, /* where available */
-				"vncProxyUnsignedApplet directive - no arguments" /* directive description */
-				),
 	AP_INIT_TAKE1(
 				"vncProxyConnectionQuery", /* directive name */
 				cmd_vncProxyConnectionQuery, /* config action routine */
@@ -716,8 +680,6 @@ static void *vncproxy_create_dir_config(apr_pool_t *p, char *dirspec)
 	cfg->local = 0;
 	cfg->congenital = 0;
 	cfg->cmode = CONFIG_MODE_DIRECTORY;
-	cfg->vncProxySignedApplet = NULL;
-	cfg->vncProxyUnsignedApplet = NULL;
 	cfg->vncProxyConnectionQuery = NULL;
 	cfg->vncProxyHelperStderr = "/var/log/vncproxy/vncproxy.log";
 	cfg->vncProxyDBDriver = "mysql";
@@ -771,8 +733,6 @@ static void *vncproxy_merge_dir_config(apr_pool_t *p, void *parent_conf, void *n
 	cfg->local = ncfg->local;
 	cfg->loc = apr_pstrdup(p, ncfg->loc);
 	cfg->dir = apr_pstrdup(p, ncfg->dir);
-	cfg->vncProxySignedApplet = ncfg->vncProxySignedApplet;
-	cfg->vncProxyUnsignedApplet = ncfg->vncProxyUnsignedApplet;
 	cfg->vncProxyConnectionQuery = ncfg->vncProxyConnectionQuery;
 	cfg->vncProxyDBDriver = ncfg->vncProxyDBDriver;
 	cfg->vncProxyDBDParams = ncfg->vncProxyDBDParams;
@@ -829,8 +789,6 @@ static void *vncproxy_create_server_config(apr_pool_t *p, server_rec *s)
 	cfg->local = 0;
 	cfg->congenital = 0;
 	cfg->cmode = CONFIG_MODE_SERVER;
-	cfg->vncProxySignedApplet = NULL;
-	cfg->vncProxyUnsignedApplet = NULL;
 	cfg->vncProxyConnectionQuery = NULL;
 	cfg->vncProxyDBDriver = "mysql";
 	cfg->vncProxyDBDParams = "";
@@ -894,10 +852,6 @@ static void *vncproxy_merge_server_config(apr_pool_t *p, void *base_conf, void *
 		(virt->vncProxyHelperStderr == NULL) ? base->vncProxyHelperStderr : virt->vncProxyHelperStderr;
 	cfg->vncProxyHelper =
 		(virt->vncProxyHelper == NULL) ? base->vncProxyHelper : virt->vncProxyHelper;
-	cfg->vncProxySignedApplet =
-		(virt->vncProxySignedApplet == NULL) ? base->vncProxySignedApplet : virt->vncProxySignedApplet;
-	cfg->vncProxyUnsignedApplet =
-		(virt->vncProxyUnsignedApplet == NULL) ? base->vncProxyUnsignedApplet : virt->vncProxyUnsignedApplet;
 	cfg->vncProxy =
 		(virt->vncProxy == 0) ? base->vncProxy : virt->vncProxy;
 	cfg->vncProxyUseModProxy =
@@ -2161,6 +2115,8 @@ static int vncproxy_translate_name(request_rec *r)
 
 	dirlen = strlen(cfg->dir);
 
+	/* No longer include option to serve applets, but keeping code to remind me how to do it in case we come back to this idea */
+	/*
 	if (strncmp(r->uri, cfg->dir, dirlen) == 0) {
 		ap_log_rerror(APLOG_MARK, APLOG_DEBUG, 0, r, "URI matches directory config");
 		if (strcmp(r->uri + dirlen, "/SignedVncViewer.jar") == 0) {
@@ -2177,6 +2133,7 @@ static int vncproxy_translate_name(request_rec *r)
 			return OK;
 		}
 	}
+	*/
 
 	return DECLINED;
 }
